@@ -25,10 +25,7 @@ except ImportError:
 from cymysql.cursors import Cursor
 from cymysql.constants.CLIENT import *
 from cymysql.constants.COMMAND import *
-try:
-    from cymysql.convertersx import escape_item
-except ImportError:
-    from cymysql.converters import escape_item
+from cymysql.converters import decoders, escape_item
 from cymysql.err import raise_mysql_exception, Warning, Error, \
      InterfaceError, DataError, DatabaseError, OperationalError, \
      IntegrityError, InternalError, NotSupportedError, ProgrammingError
@@ -133,7 +130,7 @@ class Connection(object):
                  read_default_file=None, use_unicode=None,
                  client_flag=0, cursorclass=Cursor, init_command=None,
                  connect_timeout=None, ssl=None, read_default_group=None,
-                 compress=None, named_pipe=None):
+                 compress=None, named_pipe=None, conv=decoders):
         """
         Establish a connection to the MySQL database. Accepts several
         arguments:
@@ -211,6 +208,7 @@ class Connection(object):
         self.password = passwd
         self.db = db
         self.unix_socket = unix_socket
+        self.conv=conv
         if charset:
             self.charset = charset
             self.use_unicode = True
