@@ -4,7 +4,7 @@
 import sys
 from cymysql.err import raise_mysql_exception, OperationalError
 from cymysql.constants import SERVER_STATUS
-from cymysql.converters import get_decode_values
+from cymysql.converters import decoders as default_decoders
 
 PYTHON3 = sys.version_info[0] > 2
 
@@ -41,6 +41,16 @@ def unpack_uint32(n):
         return ord(n[0]) + (ord(n[1]) << 8) + \
             (ord(n[2]) << 16) + (ord(n[3]) << 24)
 
+def get_decode_values(values, charset, fields, use_unicode, decoders):
+    r = [None] * len(values)
+    for i, value in enumerate(values):
+        if value is not None:
+            if decoders[fields[i].type_code] != default_decoders[fields[i].type_code]:
+                r[i] = decoders[fields[i].type_code](value)
+            else:
+                r[i] = decoders[fields[i].type_code](value, charset, fields[i], use_unicode)
+    return r
+
 
 class MysqlPacket(object):
     """Representation of a MySQL response packet.  Reads in the packet
@@ -159,10 +169,11 @@ class MysqlPacket(object):
     def read_decode_data(self, fields):
         values = [self.read_length_coded_string() for f in fields]
         return tuple(
-            get_decode_values(self.connection.charset,
+            get_decode_values(values,
+                self.connection.charset,
                 fields,
-                values,
-                self.connection.use_unicode)
+                self.connection.use_unicode,
+                self.connection.conv)
         )
  
     def is_ok_packet(self):
